#ifndef EL__ECMASCRIPT_MUJS_ATTRIBUTES_H
#define EL__ECMASCRIPT_MUJS_ATTRIBUTES_H

#include <mujs.h>

#ifdef __cplusplus
extern "C" {
#endif

void mjs_push_attributes(js_State *J, void *node);

#ifdef __cplusplus
}
#endif

#endif
